@@ -17,6 +17,12 @@ class SSEExchangeCalendar(MarketCalendar):
     Close Time: 3:00 PM, Asia/Shanghai
     """
     aliases = ['SSE']
+    regular_market_times = {
+        "market_open": ((None, time(9, 30)),),
+        "market_close": ((None, time(15)),),
+        "break_start": ((None, time(11,30)),),
+        "break_end": ((None, time(13)),)
+    }
 
     @property
     def name(self):
@@ -26,22 +32,6 @@ class SSEExchangeCalendar(MarketCalendar):
     def tz(self):
         return timezone('Asia/Shanghai')
 
-    @property
-    def open_time_default(self):
-        return time(9, 30, tzinfo=self.tz)
-
-    @property
-    def close_time_default(self):
-        return time(15, tzinfo=self.tz)
-
-    @property
-    def break_start(self):
-        return time(11, 30)
-
-    @property
-    def break_end(self):
-        return time(13, 0)
-
     @property
     def regular_holidays(self):
         """
